---
title: Visitors
id: visitors
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 6
kind: article
---

## Visitors

I think that I love society as much as most, and am ready enough to
fasten myself like a bloodsucker for the time to any full-blooded man
that comes in my way. I am naturally no hermit, but might possibly sit
out the sturdiest frequenter of the bar-room, if my business called me
thither.

I had three chairs in my house; one for solitude, two for friendship,
three for society. When visitors came in larger and unexpected numbers
there was but the third chair for them all, but they generally
economized the room by standing up. It is surprising how many great men
and women a small house will contain. I have had twenty-five or thirty
souls, with their bodies, at once under my roof, and yet we often
parted without being aware that we had come very near to one another.
Many of our houses, both public and private, with their almost
innumerable apartments, their huge halls and their cellars for the
storage of wines and other munitions of peace, appear to me
extravagantly large for their inhabitants. They are so vast and
magnificent that the latter seem to be only vermin which infest them. I
am surprised when the herald blows his summons before some Tremont or
Astor or Middlesex House, to see come creeping out over the piazza for
all inhabitants a ridiculous mouse, which soon again slinks into some
hole in the pavement.

One inconvenience I sometimes experienced in so small a house, the
difficulty of getting to a sufficient distance from my guest when we
began to utter the big thoughts in big words. You want room for your
thoughts to get into sailing trim and run a course or two before they
make their port. The bullet of your thought must have overcome its
lateral and ricochet motion and fallen into its last and steady course
before it reaches the ear of the hearer, else it may plough out again
through the side of his head. Also, our sentences wanted room to unfold
and form their columns in the interval. Individuals, like nations, must
have suitable broad and natural boundaries, even a considerable neutral
ground, between them. I have found it a singular luxury to talk across
the pond to a companion on the opposite side. In my house we were so
near that we could not begin to hear,—we could not speak low enough to
be heard; as when you throw two stones into calm water so near that
they break each other’s undulations. If we are merely loquacious and
loud talkers, then we can afford to stand very near together, cheek by
jowl, and feel each other’s breath; but if we speak reservedly and
thoughtfully, we want to be farther apart, that all animal heat and
moisture may have a chance to evaporate. If we would enjoy the most
intimate society with that in each of us which is without, or above,
being spoken to, we must not only be silent, but commonly so far apart
bodily that we cannot possibly hear each other’s voice in any case.
Referred to this standard, speech is for the convenience of those who
are hard of hearing; but there are many fine things which we cannot say
if we have to shout. As the conversation began to assume a loftier and
grander tone, we gradually shoved our chairs farther apart till they
touched the wall in opposite corners, and then commonly there was not
room enough.

My “best” room, however, my withdrawing room, always ready for company,
on whose carpet the sun rarely fell, was the pine wood behind my house.
Thither in summer days, when distinguished guests came, I took them,
and a priceless domestic swept the floor and dusted the furniture and
kept the things in order.

If one guest came he sometimes partook of my frugal meal, and it was no
interruption to conversation to be stirring a hasty-pudding, or
watching the rising and maturing of a loaf of bread in the ashes, in
the mean while. But if twenty came and sat in my house there was
nothing said about dinner, though there might be bread enough for two,
more than if eating were a forsaken habit; but we naturally practised
abstinence; and this was never felt to be an offence against
hospitality, but the most proper and considerate course. The waste and
decay of physical life, which so often needs repair, seemed
miraculously retarded in such a case, and the vital vigor stood its
ground. I could entertain thus a thousand as well as twenty; and if any
ever went away disappointed or hungry from my house when they found me
at home, they may depend upon it that I sympathized with them at least.
So easy is it, though many housekeepers doubt it, to establish new and
better customs in the place of the old. You need not rest your
reputation on the dinners you give. For my own part, I was never so
effectually deterred from frequenting a man’s house, by any kind of
Cerberus whatever, as by the parade one made about dining me, which I
took to be a very polite and roundabout hint never to trouble him so
again. I think I shall never revisit those scenes. I should be proud to
have for the motto of my cabin those lines of Spenser which one of my
visitors inscribed on a yellow walnut leaf for a card:—

     “Arrivéd there, the little house they fill,
         Ne looke for entertainment where none was;
     Rest is their feast, and all things at their will:
         The noblest mind the best contentment has.”

When Winslow, afterward governor of the Plymouth Colony, went with a
companion on a visit of ceremony to Massasoit on foot through the
woods, and arrived tired and hungry at his lodge, they were well
received by the king, but nothing was said about eating that day. When
the night arrived, to quote their own words,—“He laid us on the bed
with himself and his wife, they at the one end and we at the other, it
being only planks laid a foot from the ground, and a thin mat upon
them. Two more of his chief men, for want of room, pressed by and upon
us; so that we were worse weary of our lodging than of our journey.” At
one o’clock the next day Massasoit “brought two fishes that he had
shot,” about thrice as big as a bream; “these being boiled, there were
at least forty looked for a share in them. The most ate of them. This
meal only we had in two nights and a day; and had not one of us bought
a partridge, we had taken our journey fasting.” Fearing that they would
be light-headed for want of food and also sleep, owing to “the savages’
barbarous singing, (for they used to sing themselves asleep,)” and that
they might get home while they had strength to travel, they departed.
As for lodging, it is true they were but poorly entertained, though
what they found an inconvenience was no doubt intended for an honor;
but as far as eating was concerned, I do not see how the Indians could
have done better. They had nothing to eat themselves, and they were
wiser than to think that apologies could supply the place of food to
their guests; so they drew their belts tighter and said nothing about
it. Another time when Winslow visited them, it being a season of plenty
with them, there was no deficiency in this respect.

As for men, they will hardly fail one any where. I had more visitors
while I lived in the woods than at any other period in my life; I mean
that I had some. I met several there under more favorable circumstances
than I could any where else. But fewer came to see me on trivial
business. In this respect, my company was winnowed by my mere distance
from town. I had withdrawn so far within the great ocean of solitude,
into which the rivers of society empty, that for the most part, so far
as my needs were concerned, only the finest sediment was deposited
around me. Beside, there were wafted to me evidences of unexplored and
uncultivated continents on the other side.

Who should come to my lodge this morning but a true Homeric or
Paphlagonian man,—he had so suitable and poetic a name that I am sorry
I cannot print it here,—a Canadian, a woodchopper and post-maker, who
can hole fifty posts in a day, who made his last supper on a woodchuck
which his dog caught. He, too, has heard of Homer, and, “if it were not
for books,” would “not know what to do rainy days,” though perhaps he
has not read one wholly through for many rainy seasons. Some priest who
could pronounce the Greek itself taught him to read his verse in the
testament in his native parish far away; and now I must translate to
him, while he holds the book, Achilles’ reproof to Patroclus for his
sad countenance.—“Why are you in tears, Patroclus, like a young girl?”—

     “Or have you alone heard some news from Phthia?
     They say that Menœtius lives yet, son of Actor,
     And Peleus lives, son of Æacus, among the Myrmidons,
     Either of whom having died, we should greatly grieve.”

He says, “That’s good.” He has a great bundle of white-oak bark under
his arm for a sick man, gathered this Sunday morning. “I suppose
there’s no harm in going after such a thing to-day,” says he. To him
Homer was a great writer, though what his writing was about he did not
know. A more simple and natural man it would be hard to find. Vice and
disease, which cast such a sombre moral hue over the world, seemed to
have hardly any existence for him. He was about twenty-eight years old,
and had left Canada and his father’s house a dozen years before to work
in the States, and earn money to buy a farm with at last, perhaps in
his native country. He was cast in the coarsest mould; a stout but
sluggish body, yet gracefully carried, with a thick sunburnt neck, dark
bushy hair, and dull sleepy blue eyes, which were occasionally lit up
with expression. He wore a flat gray cloth cap, a dingy wool-colored
greatcoat, and cowhide boots. He was a great consumer of meat, usually
carrying his dinner to his work a couple of miles past my house,—for he
chopped all summer,—in a tin pail; cold meats, often cold woodchucks,
and coffee in a stone bottle which dangled by a string from his belt;
and sometimes he offered me a drink. He came along early, crossing my
bean-field, though without anxiety or haste to get to his work, such as
Yankees exhibit. He wasn’t a-going to hurt himself. He didn’t care if
he only earned his board. Frequently he would leave his dinner in the
bushes, when his dog had caught a woodchuck by the way, and go back a
mile and a half to dress it and leave it in the cellar of the house
where he boarded, after deliberating first for half an hour whether he
could not sink it in the pond safely till nightfall,—loving to dwell
long upon these themes. He would say, as he went by in the morning,
“How thick the pigeons are! If working every day were not my trade, I
could get all the meat I should want by hunting,—pigeons, woodchucks,
rabbits, partridges,—by gosh! I could get all I should want for a week
in one day.”

He was a skilful chopper, and indulged in some flourishes and ornaments
in his art. He cut his trees level and close to the ground, that the
sprouts which came up afterward might be more vigorous and a sled might
slide over the stumps; and instead of leaving a whole tree to support
his corded wood, he would pare it away to a slender stake or splinter
which you could break off with your hand at last.

He interested me because he was so quiet and solitary and so happy
withal; a well of good humor and contentment which overflowed at his
eyes. His mirth was without alloy. Sometimes I saw him at his work in
the woods, felling trees, and he would greet me with a laugh of
inexpressible satisfaction, and a salutation in Canadian French, though
he spoke English as well. When I approached him he would suspend his
work, and with half-suppressed mirth lie along the trunk of a pine
which he had felled, and, peeling off the inner bark, roll it up into a
ball and chew it while he laughed and talked. Such an exuberance of
animal spirits had he that he sometimes tumbled down and rolled on the
ground with laughter at any thing which made him think and tickled him.
Looking round upon the trees he would exclaim,—“By George! I can enjoy
myself well enough here chopping; I want no better sport.” Sometimes,
when at leisure, he amused himself all day in the woods with a pocket
pistol, firing salutes to himself at regular intervals as he walked. In
the winter he had a fire by which at noon he warmed his coffee in a
kettle; and as he sat on a log to eat his dinner the chickadees would
sometimes come round and alight on his arm and peck at the potato in
his fingers; and he said that he “liked to have the little _fellers_
about him.”

In him the animal man chiefly was developed. In physical endurance and
contentment he was cousin to the pine and the rock. I asked him once if
he was not sometimes tired at night, after working all day; and he
answered, with a sincere and serious look, “Gorrappit, I never was
tired in my life.” But the intellectual and what is called spiritual
man in him were slumbering as in an infant. He had been instructed only
in that innocent and ineffectual way in which the Catholic priests
teach the aborigines, by which the pupil is never educated to the
degree of consciousness, but only to the degree of trust and reverence,
and a child is not made a man, but kept a child. When Nature made him,
she gave him a strong body and contentment for his portion, and propped
him on every side with reverence and reliance, that he might live out
his threescore years and ten a child. He was so genuine and
unsophisticated that no introduction would serve to introduce him, more
than if you introduced a woodchuck to your neighbor. He had got to find
him out as you did. He would not play any part. Men paid him wages for
work, and so helped to feed and clothe him; but he never exchanged
opinions with them. He was so simply and naturally humble—if he can be
called humble who never aspires—that humility was no distinct quality
in him, nor could he conceive of it. Wiser men were demigods to him. If
you told him that such a one was coming, he did as if he thought that
any thing so grand would expect nothing of himself, but take all the
responsibility on itself, and let him be forgotten still. He never
heard the sound of praise. He particularly reverenced the writer and
the preacher. Their performances were miracles. When I told him that I
wrote considerably, he thought for a long time that it was merely the
handwriting which I meant, for he could write a remarkably good hand
himself. I sometimes found the name of his native parish handsomely
written in the snow by the highway, with the proper French accent, and
knew that he had passed. I asked him if he ever wished to write his
thoughts. He said that he had read and written letters for those who
could not, but he never tried to write thoughts,—no, he could not, he
could not tell what to put first, it would kill him, and then there was
spelling to be attended to at the same time!

I heard that a distinguished wise man and reformer asked him if he did
not want the world to be changed; but he answered with a chuckle of
surprise in his Canadian accent, not knowing that the question had ever
been entertained before, “No, I like it well enough.” It would have
suggested many things to a philosopher to have dealings with him. To a
stranger he appeared to know nothing of things in general; yet I
sometimes saw in him a man whom I had not seen before, and I did not
know whether he was as wise as Shakespeare or as simply ignorant as a
child, whether to suspect him of a fine poetic consciousness or of
stupidity. A townsman told me that when he met him sauntering through
the village in his small close-fitting cap, and whistling to himself,
he reminded him of a prince in disguise.

His only books were an almanac and an arithmetic, in which last he was
considerably expert. The former was a sort of cyclopædia to him, which
he supposed to contain an abstract of human knowledge, as indeed it
does to a considerable extent. I loved to sound him on the various
reforms of the day, and he never failed to look at them in the most
simple and practical light. He had never heard of such things before.
Could he do without factories? I asked. He had worn the home-made
Vermont gray, he said, and that was good. Could he dispense with tea
and coffee? Did this country afford any beverage beside water? He had
soaked hemlock leaves in water and drank it, and thought that was
better than water in warm weather. When I asked him if he could do
without money, he showed the convenience of money in such a way as to
suggest and coincide with the most philosophical accounts of the origin
of this institution, and the very derivation of the word _pecunia_. If
an ox were his property, and he wished to get needles and thread at the
store, he thought it would be inconvenient and impossible soon to go on
mortgaging some portion of the creature each time to that amount. He
could defend many institutions better than any philosopher, because, in
describing them as they concerned him, he gave the true reason for
their prevalence, and speculation had not suggested to him any other.
At another time, hearing Plato’s definition of a man,—a biped without
feathers,—and that one exhibited a cock plucked and called it Plato’s
man, he thought it an important difference that the _knees_ bent the
wrong way. He would sometimes exclaim, “How I love to talk! By George,
I could talk all day!” I asked him once, when I had not seen him for
many months, if he had got a new idea this summer. “Good Lord,” said
he, “a man that has to work as I do, if he does not forget the ideas he
has had, he will do well. May be the man you hoe with is inclined to
race; then, by gorry, your mind must be there; you think of weeds.” He
would sometimes ask me first on such occasions, if I had made any
improvement. One winter day I asked him if he was always satisfied with
himself, wishing to suggest a substitute within him for the priest
without, and some higher motive for living. “Satisfied!” said he; “some
men are satisfied with one thing, and some with another. One man,
perhaps, if he has got enough, will be satisfied to sit all day with
his back to the fire and his belly to the table, by George!” Yet I
never, by any manœuvring, could get him to take the spiritual view of
things; the highest that he appeared to conceive of was a simple
expediency, such as you might expect an animal to appreciate; and this,
practically, is true of most men. If I suggested any improvement in his
mode of life, he merely answered, without expressing any regret, that
it was too late. Yet he thoroughly believed in honesty and the like
virtues.

There was a certain positive originality, however slight, to be
detected in him, and I occasionally observed that he was thinking for
himself and expressing his own opinion, a phenomenon so rare that I
would any day walk ten miles to observe it, and it amounted to the
re-origination of many of the institutions of society. Though he
hesitated, and perhaps failed to express himself distinctly, he always
had a presentable thought behind. Yet his thinking was so primitive and
immersed in his animal life, that, though more promising than a merely
learned man’s, it rarely ripened to any thing which can be reported. He
suggested that there might be men of genius in the lowest grades of
life, however permanently humble and illiterate, who take their own
view always, or do not pretend to see at all; who are as bottomless
even as Walden Pond was thought to be, though they may be dark and
muddy.



Many a traveller came out of his way to see me and the inside of my
house, and, as an excuse for calling, asked for a glass of water. I
told them that I drank at the pond, and pointed thither, offering to
lend them a dipper. Far off as I lived, I was not exempted from the
annual visitation which occurs, methinks, about the first of April,
when every body is on the move; and I had my share of good luck, though
there were some curious specimens among my visitors. Half-witted men
from the almshouse and elsewhere came to see me; but I endeavored to
make them exercise all the wit they had, and make their confessions to
me; in such cases making wit the theme of our conversation; and so was
compensated. Indeed, I found some of them to be wiser than the so
called _overseers_ of the poor and selectmen of the town, and thought
it was time that the tables were turned. With respect to wit, I learned
that there was not much difference between the half and the whole. One
day, in particular, an inoffensive, simple-minded pauper, whom with
others I had often seen used as fencing stuff, standing or sitting on a
bushel in the fields to keep cattle and himself from straying, visited
me, and expressed a wish to live as I did. He told me, with the utmost
simplicity and truth, quite superior, or rather _inferior_, to any
thing that is called humility, that he was “deficient in intellect.”
These were his words. The Lord had made him so, yet he supposed the
Lord cared as much for him as for another. “I have always been so,”
said he, “from my childhood; I never had much mind; I was not like
other children; I am weak in the head. It was the Lord’s will, I
suppose.” And there he was to prove the truth of his words. He was a
metaphysical puzzle to me. I have rarely met a fellow-man on such
promising ground,—it was so simple and sincere and so true all that he
said. And, true enough, in proportion as he appeared to humble himself
was he exalted. I did not know at first but it was the result of a wise
policy. It seemed that from such a basis of truth and frankness as the
poor weak-headed pauper had laid, our intercourse might go forward to
something better than the intercourse of sages.

I had some guests from those not reckoned commonly among the town’s
poor, but who should be; who are among the world’s poor, at any rate;
guests who appeal, not to your hospitality, but to your
_hospitalality_; who earnestly wish to be helped, and preface their
appeal with the information that they are resolved, for one thing,
never to help themselves. I require of a visitor that he be not
actually starving, though he may have the very best appetite in the
world, however he got it. Objects of charity are not guests. Men who
did not know when their visit had terminated, though I went about my
business again, answering them from greater and greater remoteness. Men
of almost every degree of wit called on me in the migrating season.
Some who had more wits than they knew what to do with; runaway slaves
with plantation manners, who listened from time to time, like the fox
in the fable, as if they heard the hounds a-baying on their track, and
looked at me beseechingly, as much as to say,—

     “O Christian, will you send me back?”

One real runaway slave, among the rest, whom I helped to forward toward
the northstar. Men of one idea, like a hen with one chicken, and that a
duckling; men of a thousand ideas, and unkempt heads, like those hens
which are made to take charge of a hundred chickens, all in pursuit of
one bug, a score of them lost in every morning’s dew,—and become
frizzled and mangy in consequence; men of ideas instead of legs, a sort
of intellectual centipede that made you crawl all over. One man
proposed a book in which visitors should write their names, as at the
White Mountains; but, alas! I have too good a memory to make that
necessary.

I could not but notice some of the peculiarities of my visitors. Girls
and boys and young women generally seemed glad to be in the woods. They
looked in the pond and at the flowers, and improved their time. Men of
business, even farmers, thought only of solitude and employment, and of
the great distance at which I dwelt from something or other; and though
they said that they loved a ramble in the woods occasionally, it was
obvious that they did not. Restless committed men, whose time was all
taken up in getting a living or keeping it; ministers who spoke of God
as if they enjoyed a monopoly of the subject, who could not bear all
kinds of opinions; doctors, lawyers, uneasy housekeepers who pried into
my cupboard and bed when I was out,—how came Mrs. —— to know that my
sheets were not as clean as hers?—young men who had ceased to be young,
and had concluded that it was safest to follow the beaten track of the
professions,—all these generally said that it was not possible to do so
much good in my position. Ay! there was the rub. The old and infirm and
the timid, of whatever age or sex, thought most of sickness, and sudden
accident and death; to them life seemed full of danger,—what danger is
there if you don’t think of any?—and they thought that a prudent man
would carefully select the safest position, where Dr. B. might be on
hand at a moment’s warning. To them the village was literally a
_com-munity_, a league for mutual defence, and you would suppose that
they would not go a-huckleberrying without a medicine chest. The amount
of it is, if a man is alive, there is always _danger_ that he may die,
though the danger must be allowed to be less in proportion as he is
dead-and-alive to begin with. A man sits as many risks as he runs.
Finally, there were the self-styled reformers, the greatest bores of
all, who thought that I was forever singing,—

     This is the house that I built;
     This is the man that lives in the house that I built;

but they did not know that the third line was,—

     These are the folks that worry the man
     That lives in the house that I built.

I did not fear the hen-harriers, for I kept no chickens; but I feared
the men-harriers rather.

I had more cheering visitors than the last. Children come a-berrying,
railroad men taking a Sunday morning walk in clean shirts, fishermen
and hunters, poets and philosophers; in short, all honest pilgrims, who
came out to the woods for freedom’s sake, and really left the village
behind, I was ready to greet with,—“Welcome, Englishmen! welcome,
Englishmen!” for I had had communication with that race.


